@@ -12,7 +12,7 @@ from lino.core.roles import SiteStaff
 
 from .choicelists import AddressTypes, DataSources
 from .mixins import AddressOwner
-
+from lino.core import constants
 
 class Address(AddressLocation):
 
@@ -125,7 +125,7 @@ class AddressesByPartner(Addresses):
     stay_in_grid = True
     window_size = (80, 20)
 
-    # display_mode_main = 'summary'
+    # display_mode = ((None, constants.DISPLAY_MODE_SUMMARY), )
 
     # @classmethod
     # def get_table_summary(self, obj, ar):
