@@ -50,4 +50,4 @@ class Plugin(ad.Plugin):
         mg = self.get_menu_group()
         m = m.add_menu(mg.app_label, mg.verbose_name)
         m.add_action('albums.AllFiles')
-        m.add_action('albums.FileUsages')
+        # m.add_action('albums.FileUsages')
