@@ -78,7 +78,7 @@ class MoveEntryNext(dd.MultipleRowAction):
     custom_handler = True
     # icon_name = 'date_next'
     show_in_workflow = True
-    show_in_bbar = False
+    show_in_toolbar = False
     help_text = _("Move this event to next available date")
     readonly = False
 
@@ -87,7 +87,7 @@ class MoveEntryNext(dd.MultipleRowAction):
             return False
         if state.fixed:
             return False
-        return super(MoveEntryNext, self).get_action_permission(
+        return super().get_action_permission(
             ar, obj, state)
 
     def run_on_row(self, obj, ar):
@@ -108,7 +108,7 @@ class UpdateEntries(dd.MultipleRowAction):
     def get_action_permission(self, ar, obj, state):
         if not obj.has_auto_events():
             return False
-        return super(UpdateEntries, self).get_action_permission(
+        return super().get_action_permission(
             ar, obj, state)
 
     def run_on_row(self, obj, ar):
@@ -123,6 +123,7 @@ class UpdateEntriesByEvent(UpdateEntries):
             return False
         if not obj.owner.has_auto_events():
             return False
+        # Do NOT inherit from UpdateEntries:
         return super(UpdateEntries, self).get_action_permission(
             ar, obj, state)
 
@@ -139,7 +140,7 @@ class EventGenerator(dd.Model):
 
     @classmethod
     def get_registrable_fields(cls, site):
-        for f in super(EventGenerator, cls).get_registrable_fields(site):
+        for f in super().get_registrable_fields(site):
             yield f
         yield "user"
 
@@ -147,7 +148,7 @@ class EventGenerator(dd.Model):
         for ee in self.get_existing_auto_events():
             if ee.is_user_modified():
                 return _("Cannot delete {} because it has user-modified calendar entries.").format(self)
-        return super(EventGenerator, self).disable_delete(ar)
+        return super().disable_delete(ar)
 
     def delete(self):
         """
@@ -158,7 +159,7 @@ class EventGenerator(dd.Model):
         for ee in self.get_existing_auto_events():
             assert not ee.is_user_modified()
             ee.delete()
-        super(EventGenerator, self).delete()
+        super().delete()
 
     def get_recurrence_set(self):
         raise NotImplementedError()
@@ -369,12 +370,14 @@ class EventGenerator(dd.Model):
         #     raise Exception("20180321")
         last_date = None
         with translation.override(self.get_events_language()):
+            # print("20221129 max_events", max_events)
             while max_events is None or event_no < max_events:
                 if date > until:
                     ar.info("Reached upper date limit %s for %s",
                             until, event_no)
                     break
                 event_no += 1
+                # print("20221129 event_no", event_no)
                 if ignore_before and date < ignore_before:
                     ar.info("Ignore %d because it is before %s",
                             event_no, ignore_before)
@@ -398,7 +401,9 @@ class EventGenerator(dd.Model):
                     ee = existing.pop(event_no, None)
                     if ee is None:
                         wanted.append(we)
+                        # print("20221129 wanted event", ee)
                     elif ee.is_user_modified():
+                        # print("20221129 is_user_modified", ee)
                         if last_date and ee.start_date < last_date:
                             msg = _("Automatic entry {} ({}) goes back in time.")
                             raise Warning(msg.format(ee.auto_type, ee.start_date))
@@ -408,6 +413,7 @@ class EventGenerator(dd.Model):
                             % (ee.summary, date, ee.start_date))
                         date = ee.start_date
                     else:
+                        # print("20221129 compare_auto_event", ee, we)
                         rset.compare_auto_event(ee, we)
                         # we don't need to append it to wanted because
                         # compare_auto_event() saves any changes immediately.
@@ -416,7 +422,7 @@ class EventGenerator(dd.Model):
                 date = rset.get_next_suggested_date(ar, date)
                 date = rset.find_start_date(date)
                 if date is None:
-                    ar.info("Could not find next date after %s.", event_no)
+                    ar.info("Could not find next date after %s (%s).", last_date, event_no)
                     break
 
         # if there is something left in existing, keep only user-modified
@@ -426,6 +432,8 @@ class EventGenerator(dd.Model):
                 wanted.append(ee)
             else:
                 unwanted.append(ee)
+
+        # print("20221124", wanted)
         return wanted, unwanted
 
     def move_event_next(self, we, ar):
@@ -540,7 +548,7 @@ class RecurrenceSet(Started, Ended):
         verbose_name_plural = _("Recurrence Sets")
 
     every_unit = Recurrencies.field(
-        _("Recurrency"), default='monthly', blank=True)
+        _("Recurrency"), blank=True)  # default='monthly'
     every = models.IntegerField(_("Repeat every"), default=1)
     positions = models.CharField(_("Positions"), blank=True, max_length=50)
 
@@ -560,11 +568,11 @@ class RecurrenceSet(Started, Ended):
     def on_analyze(cls, site):
         cls.WEEKDAY_FIELDS = dd.fields_list(
             cls, 'monday tuesday wednesday thursday friday saturday  sunday')
-        super(RecurrenceSet, cls).on_analyze(site)
+        super().on_analyze(site)
 
     @classmethod
     def get_registrable_fields(cls, site):
-        for f in super(RecurrenceSet, cls).get_registrable_fields(site):
+        for f in super().get_registrable_fields(site):
             yield f
         for f in cls.WEEKDAY_FIELDS:
             yield f
@@ -584,14 +592,14 @@ class RecurrenceSet(Started, Ended):
         #     self.max_events = 1
         #     self.positions = ''
         #     self.every = 0
-        super(RecurrenceSet, self).full_clean(*args, **kw)
+        super().full_clean(*args, **kw)
         # if self.positions:
         #     if self.every != 1:
         #         raise ValidationError(
         #             "Cannot specify positions together with repeat value!")
 
     def disabled_fields(self, ar):
-        rv = super(RecurrenceSet, self).disabled_fields(ar)
+        rv = super().disabled_fields(ar)
         if self.every_unit == Recurrencies.once:
             rv.add('max_events')
             rv.add('every')
@@ -612,7 +620,9 @@ class RecurrenceSet(Started, Ended):
 
     @dd.displayfield(_("When"))
     def weekdays_text(self, ar=None):
-        if self.every_unit == Recurrencies.once:
+        if self.every_unit is None:
+            return _("No recurrency")
+        elif self.every_unit == Recurrencies.once:
             if self.end_date and self.end_date != self.start_date:
                 return gettext("{0}-{1}").format(
                     dd.fds(self.start_date), dd.fds(self.end_date))
@@ -842,7 +852,7 @@ class Reservation(RecurrenceSet, EventGenerator, Registrable, UserAuthored):
     def on_analyze(cls, site):
         if cls.workflow_state_field is None:
             raise Exception("{} has no workflow_state_field".format(cls))
-        super(Reservation, cls).on_analyze(site)
+        super().on_analyze(site)
         ic = cls.workflow_state_field.choicelist
         k = 'auto_update_calendar'
         if not hasattr(ic, k):
@@ -852,7 +862,7 @@ class Reservation(RecurrenceSet, EventGenerator, Registrable, UserAuthored):
 
     @classmethod
     def get_simple_parameters(cls):
-        s = list(super(Reservation, cls).get_simple_parameters())
+        s = list(super().get_simple_parameters())
         s.append('room')
         return s
 
@@ -871,13 +881,13 @@ class Reservation(RecurrenceSet, EventGenerator, Registrable, UserAuthored):
 
     @classmethod
     def get_registrable_fields(cls, site):
-        for f in super(Reservation, cls).get_registrable_fields(site):
+        for f in super().get_registrable_fields(site):
             yield f
         yield 'room'
         yield 'max_date'
 
     def after_state_change(self, ar, old, target_state):
-        super(Reservation, self).after_state_change(ar, old, target_state)
+        super().after_state_change(ar, old, target_state)
         if target_state.auto_update_calendar:
             self.update_reminders(ar)
 
@@ -914,14 +924,14 @@ Whether this is private, public or between."""))  # iCal:CLASS
     def save(self, *args, **kw):
         if self.user is not None and self.access_class is None:
             self.access_class = self.user.access_class
-        super(Component, self).save(*args, **kw)
+        super().save(*args, **kw)
 
     def on_duplicate(self, ar, master):
         self.auto_type = None
-        super(Component, self).on_duplicate(ar, master)
+        super().on_duplicate(ar, master)
 
     def disabled_fields(self, ar):
-        rv = super(Component, self).disabled_fields(ar)
+        rv = super().disabled_fields(ar)
         if self.auto_type:
             rv |= self.DISABLED_AUTO_FIELDS
         return rv
@@ -942,7 +952,7 @@ Whether this is private, public or between."""))  # iCal:CLASS
     def summary_row(self, ar, **kw):
         # dd.logger.info("20120217 Component.summary_row() %s", ar.renderer)
         #~ if self.owner and not self.auto_type:
-        for e in super(Component, self).summary_row(ar):
+        for e in super().summary_row(ar):
             yield e
         # yield ar.obj2html(self)
         if self.start_time:
@@ -959,7 +969,7 @@ Whether this is private, public or between."""))  # iCal:CLASS
         #     html.extend(ar.summary_row(self.project, **kw))
         #     html.append(")")
         # return html
-        #~ return super(Event,self).summary_row(ui,rr,**kw)
+        #~ return super().summary_row(ui,rr,**kw)
 
     # def get_change_owner(self):
     #     return self.project
