@@ -186,7 +186,7 @@ class Tasks(dd.Table):
     # @classmethod
     # def get_request_queryset(self, ar, **kwargs):
     #     # logger.info("20121010 Clients.get_request_queryset %s",ar.param_values)
-    #     qs = super(Tasks, self).get_request_queryset(ar, **kwargs)
+    #     qs = super().get_request_queryset(ar, **kwargs)
     #
     #     if ar.param_values.user:
     #         qs = qs.filter(user=ar.param_values.user)
@@ -205,7 +205,7 @@ class Tasks(dd.Table):
 
     # @classmethod
     # def get_title_tags(self, ar):
-    #     for t in super(Tasks, self).get_title_tags(ar):
+    #     for t in super().get_title_tags(ar):
     #         yield t
     #     if ar.param_values.start_date or ar.param_values.end_date:
     #         yield str(_("Dates %(min)s to %(max)s") % dict(
@@ -255,7 +255,7 @@ class MyTasks(Tasks):
     @classmethod
     def param_defaults(self, ar, **kw):
         cfg = dd.plugins.cal
-        kw = super(MyTasks, self).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         assert ar.get_user().is_authenticated
         kw.update(user=ar.get_user())
         kw.update(state=TaskStates.todo)
@@ -338,7 +338,7 @@ class Guests(dd.Table):
 
     @classmethod
     def get_request_queryset(self, ar, **kwargs):
-        qs = super(Guests, self).get_request_queryset(ar, **kwargs)
+        qs = super().get_request_queryset(ar, **kwargs)
 
         if isinstance(qs, list):
             return qs
@@ -368,7 +368,7 @@ class Guests(dd.Table):
 
     @classmethod
     def get_title_tags(self, ar):
-        for t in super(Guests, self).get_title_tags(ar):
+        for t in super().get_title_tags(ar):
             yield t
         pv = ar.param_values
         if pv.start_date or pv.end_date:
@@ -404,7 +404,7 @@ class GuestsByEvent(Guests):
 
     # @classmethod
     # def get_create_permission(cls, ar):
-    #     if not super(GuestsByEvent, cls).get_create_permission(ar):
+    #     if not super().get_create_permission(ar):
     #         return False
     #     mi = ar.master_instance
     #     if mi and mi.can_edit_guests_manually():
@@ -413,7 +413,7 @@ class GuestsByEvent(Guests):
 
     # @classmethod
     # def disable_delete(cls, obj, ar):
-    #     msg = super(GuestsByEvent, cls).disable_delete(obj, ar)
+    #     msg = super().disable_delete(obj, ar)
     #     if msg is not None:
     #         return msg
     #     mi = ar.master_instance
@@ -445,7 +445,7 @@ class GuestsByPartner(Guests):
 
     @classmethod
     def param_defaults(self, ar, **kw):
-        kw = super(GuestsByPartner, self).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         # kw.update(event_state=EntryStates.took_place)
         kw.update(end_date=dd.today(7))
         return kw
@@ -463,18 +463,18 @@ class MyPresences(Guests):
         # logger.info("20130809 MyPresences")
         if ar.get_user().partner is None:
             raise Warning("Action not available for users without partner")
-        return super(MyPresences, self).get_request_queryset(ar, **kwargs)
+        return super().get_request_queryset(ar, **kwargs)
 
     @classmethod
     def get_row_permission(cls, obj, ar, state, ba):
         if ar.get_user().partner is None:
             return False
-        return super(MyPresences, cls).get_row_permission(
+        return super().get_row_permission(
             obj, ar, state, ba)
 
     @classmethod
     def param_defaults(self, ar, **kw):
-        kw = super(MyPresences, self).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         u = ar.get_user()
         if u is not None:
             kw.update(partner=u.partner)
@@ -485,7 +485,7 @@ class MyPresences(Guests):
     # @classmethod
     # def get_request_queryset(self,ar):
         # ar.master_instance = ar.get_user().partner
-        # return super(MyPresences,self).get_request_queryset(ar)
+        # return super().get_request_queryset(ar)
 
 # class MyPendingInvitations(Guests):
 class MyPendingPresences(MyPresences):
@@ -496,7 +496,7 @@ class MyPendingPresences(MyPresences):
 
     @classmethod
     def param_defaults(self, ar, **kw):
-        kw = super(MyPendingPresences, self).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         # kw.update(partner=ar.get_user().partner)
         # kw.update(user=None)
         kw.update(guest_state=GuestStates.invited)
@@ -512,7 +512,7 @@ class MyGuests(Guests):
 
     @classmethod
     def param_defaults(self, ar, **kw):
-        kw = super(MyGuests, self).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         kw.update(user=ar.get_user())
         kw.update(guest_state=GuestStates.invited)
         kw.update(start_date=settings.SITE.today())
@@ -581,7 +581,7 @@ class RecurrentEvents(dd.Table):
         # if not action.readonly:
             # if row.user != user and user.level < UserLevel.manager:
                 # return False
-        # if not super(Components,cls).get_row_permission(action,user,row):
+        # if not super().get_row_permission(action,user,row):
             # return False
         # return True
 
@@ -652,7 +652,7 @@ class Events(dd.Table):
     # def setup_parameters(cls, params):
     #     cls.params_layout = rt.models.cal.Event.params_layout
     #     params = rt.models.cal.Event.setup_parameters(params)
-    #     return super(Events, cls).setup_parameters(params)
+    #     return super().setup_parameters(params)
 
 
     @classmethod
@@ -663,14 +663,14 @@ class Events(dd.Table):
     # @classmethod
     # def get_request_queryset(self, ar, **kwargs):
     #     # print("20181121a get_request_queryset", self)
-    #     qs = super(Events, self).get_request_queryset(ar, **kwargs)
+    #     qs = super().get_request_queryset(ar, **kwargs)
     #     pv = ar.param_values
     #     return rt.models.cal.Event.calendar_param_filter(qs, pv)
 
 
     @classmethod
     def get_title_tags(self, ar):
-        for t in super(Events, self).get_title_tags(ar):
+        for t in super().get_title_tags(ar):
             yield t
         pv = ar.param_values
         if pv.start_date or pv.end_date:
@@ -707,7 +707,7 @@ class Events(dd.Table):
 
     @classmethod
     def param_defaults(self, ar, **kw):
-        kw = super(Events, self).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         kw.update(start_date=settings.SITE.site_config.hide_events_before)
         return kw
 
@@ -746,7 +746,7 @@ class PublicEntries(Events):
 
     @classmethod
     def param_defaults(self, ar, **kw):
-        kw = super(PublicEntries, self).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         # kw.update(show_appointments=dd.YesNo.yes)
         kw.update(start_date=settings.SITE.today())
         # kw.update(end_date=settings.SITE.today())
@@ -763,7 +763,7 @@ class EntriesByDay(Events):
 
     @classmethod
     def param_defaults(self, ar, **kw):
-        kw = super(EntriesByDay, self).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         kw.update(show_appointments=dd.YesNo.yes)
         kw.update(start_date=settings.SITE.today())
         kw.update(end_date=settings.SITE.today())
@@ -772,7 +772,7 @@ class EntriesByDay(Events):
     @classmethod
     def create_instance(self, ar, **kw):
         kw.update(start_date=ar.param_values.start_date)
-        return super(EntriesByDay, self).create_instance(ar, **kw)
+        return super().create_instance(ar, **kw)
 
     @classmethod
     def get_title_base(self, ar):
@@ -946,7 +946,7 @@ def get_calendar_summary(cls, obj, ar):
     cal = CalendarRenderer(cls.model)
     # sar = ar.spawn(parent=ar, master_instance=obj)
     # sar = ar.actor.request(parent=ar, master_instance=obj)
-    sar = cls.request_from(ar, master_instance=obj)
+    sar = cls.request(parent=ar, master_instance=obj)
     # sar = cls.request(parent=ar, master_instance=obj)
     # print("20181121 {}".format(ar.actor))
     # print("20181121 {}".format(cls.get_filter_kw(sar)))
@@ -1019,7 +1019,7 @@ if settings.SITE.project_model:
         mi = ar.master_instance
         if mi is not None:
             kw['project'] = mi
-        return super(EntriesByProject, cls).create_instance(ar, **kw)
+        return super().create_instance(ar, **kw)
 
 
 
@@ -1040,7 +1040,7 @@ class EntriesByGuest(Events):
 
     @classmethod
     def param_defaults(self, ar, **kw):
-        kw = super(EntriesByGuest, self).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         # kw.update(event_state=EntryStates.took_place)
         kw.update(end_date=dd.today(7))
         return kw
@@ -1052,7 +1052,7 @@ class EntriesByGuest(Events):
             Guest = rt.models.cal.Guest
             if not Guest.objects.filter(partner=mi, event=obj).exists():
                 Guest.objects.create(partner=mi, event=obj)
-        super(EntriesByGuest, cls).after_create_instance(obj, ar)
+        super().after_create_instance(obj, ar)
 
 
 class OneEvent(Events):
@@ -1075,7 +1075,7 @@ class MyEntries(Events):
 
     @classmethod
     def param_defaults(self, ar, **kw):
-        kw = super(MyEntries, self).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         kw.update(user=ar.get_user())
         kw.update(show_appointments=dd.YesNo.yes)
         # kw.update(assigned_to=ar.get_user())
@@ -1087,7 +1087,7 @@ class MyEntries(Events):
     @classmethod
     def create_instance(self, ar, **kw):
         kw.update(start_date=ar.param_values.start_date)
-        return super(MyEntries, self).create_instance(ar, **kw)
+        return super().create_instance(ar, **kw)
 
 
 class MyEntriesToday(MyEntries):
@@ -1097,7 +1097,7 @@ class MyEntriesToday(MyEntries):
 
     @classmethod
     def param_defaults(self, ar, **kw):
-        kw = super(MyEntriesToday, self).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         kw.update(end_date=dd.today())
         return kw
 
@@ -1109,7 +1109,7 @@ class MyAssignedEvents(MyEntries):
 
     @classmethod
     def param_defaults(self, ar, **kw):
-        kw = super(MyAssignedEvents, self).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         kw.update(user=None)
         kw.update(assigned_to=ar.get_user())
         return kw
@@ -1132,7 +1132,7 @@ class OverdueAppointments(Events):
 
     @classmethod
     def param_defaults(self, ar, **kw):
-        kw = super(OverdueAppointments, self).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         kw.update(observed_event=EventEvents.pending)
         kw.update(end_date=settings.SITE.today(-1))
         kw.update(show_appointments=dd.YesNo.yes)
@@ -1153,7 +1153,7 @@ class MyUnconfirmedAppointments(MyEntries):
 
     @classmethod
     def param_defaults(self, ar, **kw):
-        kw = super(MyUnconfirmedAppointments, self).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         # kw.update(observed_event=EventEvents.pending)
         # kw.update(state=EntryStates.draft)
         kw.update(start_date=settings.SITE.today(-14))
