@@ -203,6 +203,14 @@ class PartnerRelated(dd.Model):
         if p is not None:
             return p.language
 
+    def get_company(self):
+        return self.partner.get_mti_child('company')
+    company = property(get_company)
+
+    def get_person(self):
+        return self.partner.get_mti_child('person')
+    person = property(get_person)
+
     def get_recipient(self):
         return self.get_partner()
     recipient = property(get_recipient)
