@@ -22,6 +22,7 @@ from lino.mixins.sequenced import Sequenced
 from lino.mixins.periods import DateRangeObservable
 from lino.modlib.printing.mixins import Printable
 from lino.modlib.uploads.mixins import UploadController
+from lino.modlib.memo.mixins import MemoReferrable
 from lino.utils import join_words
 from lino.utils.addressable import Addressable
 from lino.utils.media import TmpMediaFile
@@ -228,7 +229,7 @@ class ImportText(dd.Action):
 
 class Partner(Duplicable, ContactDetailsOwner, mixins.Polymorphic,
               AddressOwner, UploadController, Feasible, Printable,
-              DateRangeObservable, VatSubjectable):
+              DateRangeObservable, VatSubjectable, MemoReferrable):
     preferred_foreignkey_width = 20
     # preferred width for ForeignKey fields to a Partner
 
@@ -503,6 +504,8 @@ class Person(Human, Born, Partner):
         verbose_name_plural = _("Persons")
         ordering = ['last_name', 'first_name']
 
+    memo_command = 'person'
+
     def get_after_salutation_words(self):
         if self.prefix:
             yield self.prefix
@@ -623,6 +626,8 @@ class Company(Partner):
         verbose_name = _("Organization")
         verbose_name_plural = _("Organizations")
 
+    memo_command = 'company'
+
     type = dd.ForeignKey('contacts.CompanyType', blank=True, null=True)
 
     def get_full_name(self, salutation=True, **salutation_options):
