@@ -29,7 +29,7 @@ class Plugin(ad.Plugin):
         self.pupil_name_fields = set(self.pupil_name_fields.split())
         # self.pupil_name_fields = fields_list(
         #      site.models.courses.Enrolment, self.pupil_name_fields)
-        super(Plugin, self).on_plugins_loaded(site)
+        super().on_plugins_loaded(site)
 
     def on_site_startup(self, site):
         from lino.mixins import Contactable
@@ -52,7 +52,7 @@ class Plugin(ad.Plugin):
         # # site.models.courses.EnrolmentStates.verbose_name = format_lazy(_("{} state"), name)
         # site.models.courses.EnrolmentStates.verbose_name_plural = format_lazy(_("{} states"), name)
 
-        super(Plugin, self).on_site_startup(site)
+        super().on_site_startup(site)
 
     def setup_main_menu(self, site, user_type, main):
         m = main.add_menu(self.app_label, self.verbose_name)
@@ -85,7 +85,7 @@ class Plugin(ad.Plugin):
         m.add_action('courses.CourseStates')
 
     def get_dashboard_items(self, user):
-        for x in super(Plugin, self).get_dashboard_items(user):
+        for x in super().get_dashboard_items(user):
             yield x
         if user.is_authenticated:
             yield self.site.models.courses.MyCoursesGiven
