@@ -11,7 +11,6 @@ from lino_xl.lib.ledger.fields import DcAmountField
 from lino_xl.lib.ledger.choicelists import DC, VoucherTypes
 from lino_xl.lib.ledger.roles import LedgerUser, LedgerStaff
 from lino_xl.lib.ledger.mixins import ProjectRelated
-from lino_xl.lib.ledger.mixins import PartnerRelated
 from lino_xl.lib.sepa.mixins import BankAccount
 from lino.modlib.printing.mixins import Printable
 
@@ -37,7 +36,7 @@ class ShowSuggestions(dd.Action):
     # started as a copy of ShowSlaveTable
     # TABLE2ACTION_ATTRS = tuple('help_text icon_name label sort_index'.split())
     TABLE2ACTION_ATTRS = tuple('help_text label sort_index'.split())
-    show_in_bbar = False
+    show_in_toolbar = False
     show_in_workflow = True
     readonly = False
 
