@@ -2,30 +2,36 @@ import json
 import requests
 import datetime
 import logging; logger = logging.getLogger(__name__)
-from pathlib import Path
 from dateutil.parser import parse
+from importlib import import_module
+from pathlib import Path
 
 try:
     from google.oauth2.credentials import Credentials
     from google.auth.exceptions import RefreshError
     from googleapiclient._auth import is_valid, refresh_credentials
     from googleapiclient.discovery import build
+    from social_django.models import UserSocialAuth
 except ImportError:
-    pass
+    class UserSocialAuth:
+        pass
 
+from django.conf import settings
 from django.utils import timezone
 from lino.core.site import has_socialauth
 
 from lino.api import dd
+user_mod = import_module([app for app in settings.INSTALLED_APPS if app.endswith('users')][0] + ".models")
+User = user_mod.User
 
 
-def get_credentials(me):
+def get_credentials(user: UserSocialAuth) -> Credentials:
 
     with open(dd.plugins.google.client_secret_file) as f:
         client_secret = json.load(f)
 
-    if type(me.extra_data['scopes']) == str:
-        me.extra_data['scopes'] = me.extra_data['scopes'].split()
+    if type(user.extra_data['scopes']) == str:
+        user.extra_data['scopes'] = user.extra_data['scopes'].split()
 
     def get_expiry(creds):
         from_auth_time_and_delta = datetime.datetime.fromtimestamp(
@@ -39,35 +45,34 @@ def get_credentials(me):
         token_uri=client_secret['web']['token_uri'],
         client_id=client_secret['web']['client_id'],
         client_secret=client_secret['web']['client_secret'],
-        token=me.extra_data['access_token'],
-        refresh_token=me.extra_data['refresh_token'],
-        rapt_token=me.extra_data['rapt_token'],
-        id_token=me.extra_data['id_token'],
-        expiry=get_expiry(me.extra_data),
-        scopes=me.extra_data['scopes']
+        token=user.extra_data['access_token'],
+        refresh_token=user.extra_data['refresh_token'],
+        rapt_token=user.extra_data['rapt_token'],
+        id_token=user.extra_data['id_token'],
+        expiry=get_expiry(user.extra_data),
+        scopes=user.extra_data['scopes']
     )
 
     if not is_valid(creds):
         try:
             refresh_credentials(creds)
-            me.extra_data['access_token'] = creds.token
-            me.extra_data['expiry'] = datetime.datetime.timestamp(creds.expiry)
-            me.extra_data['refresh_token'] = creds.refresh_token
-            me.extra_data['rapt_token'] = creds.rapt_token
-            me.full_clean()
-            me.save()
+            user.extra_data['access_token'] = creds.token
+            user.extra_data['expiry'] = datetime.datetime.timestamp(creds.expiry)
+            user.extra_data['refresh_token'] = creds.refresh_token
+            user.extra_data['rapt_token'] = creds.rapt_token
+            user.full_clean()
+            user.save()
         except RefreshError as e:
             requests.post('https://oauth2.googleapis.com/revoke',
                 params={'token': creds.token},
                 headers={'content-type': 'application/x-www-form-urlencoded'})
-            logger(f"{me.user}'s Token has been revoked, because of this:\n{e}\nNeeds re-authentication.")
-            me.delete()
+            logger(f"{user.user}'s Token has been revoked, because of this:\n{e}\nNeeds re-authentication.")
+            user.delete()
 
     return creds
 
-def get_resource(user):
-    from social_django.models import UserSocialAuth
-    social_user = UserSocialAuth.objects.get(user=user, provider='google')
+def get_resource(user: User):
+    social_user = user.social_auth.get(provider='google')
     creds = get_credentials(social_user)
     return build('calendar', 'v3', credentials=creds)
 
@@ -79,7 +84,7 @@ def map_calendar_into_dbModel(cls, cal):
     return calendar
 
 def map_event_into_dbModel(cls, event, user_s_cal):
-    e = cls.objects.get_or_create(
+    e, _ = cls.objects.get_or_create(
         google_id=event['id'], google_calendar=user_s_cal.calendar)
     e.status = event.get('status') # possible values are 'confirmed', 'tentative', 'cancelled'
     e.summary = event.get('summary') # The title of the event
@@ -87,28 +92,41 @@ def map_event_into_dbModel(cls, event, user_s_cal):
     e.sequence = event.get('sequence')
 
     def resolve_datetime(stamp):
-        if hasattr(stamp, 'timeZone'):
-            with timezone.override(stamp['timeZone']):
-                dt = parse(stamp['dateTime']).replace(
-                    tzinfo=timezone.get_current_timezone())
-            dt = timezone.make_naive(dt)
-        else:
-            dt = timezone.make_naive(parse(stamp['dateTime']))
+        return timezone.make_naive(parse(stamp))
+
+    def resolve_date_time(stamp):
+        dt = resolve_datetime(stamp)
         return dt.date(), dt.time()
 
-    if hasattr(event, 'start'):
-        if hasattr(event['start'], 'dateTime'):
-            e.start_date, e.start_time = resolve_datetime(event['start'])
+    if start := event.get('start'):
+        if dateTime := start.get('dateTime'):
+            e.start_date, e.start_time = resolve_date_time(dateTime)
         else:
             e.start_date = datetime.date(
-                *map(int, event['start']['date'].split('-')))
+                *map(int, start['date'].split('-')))
+    elif originalStart := event.get('originalStartTime'):
+        if dateTime := originalStart.get('dateTime'):
+            e.start_date, e.start_time = resolve_date_time(dateTime)
+        else:
+            e.start_date = datetime.date(
+                *map(int, originalStart['date'].split('-')))
 
-    if hasattr(event, 'end'):
-        if hasattr(event['end'], 'dateTime'):
-            e.end_date, e.end_time = resolve_datetime(event['end'])
+    if end := event.get('end'):
+        if dateTime := end.get('dateTime'):
+            e.end_date, e.end_time = resolve_date_time(dateTime)
         else:
             e.end_date = datetime.date(
-                *map(int, event['end']['date'].split('-')))
+                *map(int, end['date'].split('-')))
 
     e.location = event.get('location')
+
+    if created := event.get('created'):
+        e.created = resolve_datetime(created)
+
+    if updated := event.get('updated'):
+        e.modified = resolve_datetime(updated)
+
+    return e
+
+def map_recurrent_event(cls, event, user_s_cal):
     pass
