@@ -1,18 +1,24 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2016-2021 Rumma & Ko Ltd
+# Copyright 2016-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
-from django.db import models
 from datetime import timedelta
 from etgen.html import E, join_elems
-from lino.api import dd, _, gettext
-from lino.core.gfks import gfk2lookup
+
+from django.db import models
+from django.contrib.contenttypes.fields import GenericRelation
+from django.utils.text import format_lazy
+from lino.api import dd, rt, _, gettext
+from lino.core.gfks import gfk2lookup, GenericForeignKey, ContentType
+from lino.modlib.gfks.fields import GenericForeignKeyIdField
+from lino.utils import ONE_DAY
+from lino.mixins.periods import rangefmt
 from lino_xl.lib.ledger.utils import ZERO
 from lino_xl.lib.cal.utils import day_and_month
 from lino_xl.lib.cal.choicelists import DurationUnits
-from lino.utils import ONE_DAY
+from lino_xl.lib.ledger.roles import LedgerUser, LedgerStaff
+from lino_xl.lib.ledger.choicelists import VoucherTypes
 
-from django.contrib.contenttypes.fields import GenericRelation
 
 MAX_SHOWN = 3  # maximum number of invoiced events shown in invoicing_info
 
@@ -22,13 +28,15 @@ class Periodicity(dd.Choice):
     renew_before = None
 
     def __init__(self, value, text, renew_unit, renew_every, renew_before):
-        super(Periodicity, self).__init__(value, text, value)
+        super().__init__(value, text, value)
         self.renew_unit = renew_unit
         self.renew_every = renew_every
         self.renew_before = renew_before
 
 class Periodicities(dd.ChoiceList):
     item_class = Periodicity
+    verbose_name = _("Subscription periodicity")
+    verbose_name_plural = _("Subscription periodicities")
 
 add = Periodicities.add_item
 add("m", _("Monthly"), DurationUnits.months, 1, 7)
@@ -41,8 +49,10 @@ class InvoicingInfo(object):
     invoiced_events = 0
     used_events = []
     invoicings = None
-    invoicing_min_date = None
-    invoicing_max_date = None
+    sub_start = None
+    sub_end = None
+    # invoicing_min_date = None
+    # invoicing_max_date = None
     # tariff = None
     # 20210724
     invoiceable_product = None
@@ -53,7 +63,7 @@ class InvoicingInfo(object):
     max_asset = None
 
     def __init__(self, enr, min_date, max_date):
-        # print("20220507 InvoicingInfo()", enr)
+        # print("20221223 InvoicingInfo() for {} ({}-{})".format(enr, min_date, max_date))
         self.generator = enr
         self.min_date = min_date
         self.max_date = max_date
@@ -77,21 +87,28 @@ class InvoicingInfo(object):
 
         sub = enr.get_invoicing_periodicity(product)
         if sub is not None:
-            last_invoicing = self.invoicings.last()
-            if last_invoicing is None:
-                # next_date = enr.get_invoiceable_start_date(max_date)
-                paid_until = start_date - ONE_DAY
-            else:
-                paid_until = last_invoicing.voucher.invoicing_max_date
-            next_date = paid_until - timedelta(days=sub.renew_before)
-            if next_date < max_date:
-                # next invoicing date not yet reached
+            sub_start = start_date
+            sub_end = sub.renew_unit.add_duration(sub_start, sub.renew_every) - ONE_DAY
+            # print("20221223 subscription", rangefmt([sub_start, sub_end]))
+            for i in self.invoicings:
+                sub_start = sub_end + ONE_DAY
+                sub_end = sub.renew_unit.add_duration(sub_start, sub.renew_every) - ONE_DAY
+                # print("20221223 found existing invoicing until", sub_end)
+            next_date = sub_start - timedelta(days=sub.renew_before)
+            if min_date and next_date < min_date:
+                # print("20221223 subscription is not yet started on", min_date)
+                return
+            if next_date > max_date:
+                # print("20221223 no need to invoice renewal {} on {}".format(next_date, max_date))
+                # next renewal date not yet reached
                 return
-            self.asset_to_buy = 1
-            self.invoicing_min_date = paid_until + ONE_DAY
-            self.invoicing_max_date = sub.renew_unit.add_duration(
-                paid_until, sub.renew_every)
             # self.invoiceable_product = product
+            self.asset_to_buy = self.invoiceable_qty = 1
+            self.sub_start = sub_start
+            self.sub_end = sub_end
+            self.invoiceable_product = product
+            # print("20221223 renewal date reached", enr, self.invoiceable_qty, self.number_of_events, self.asset_to_buy)
+            assert self.number_of_events is None and self.asset_to_buy is not None
             return
 
         self.invoiced_events = enr.get_invoiceable_free_events() or 0
@@ -220,6 +237,91 @@ class InvoicingInfo(object):
 #         # return None
 
 
+# class UNDEFINED:
+#     pass
+
+
+class InvoicingArea(dd.Choice):
+    # journal_table = None
+
+    def get_source_journals(self):
+        for o in rt.models.invoicing.FollowUpRule.objects.filter(invoicing_area=self):
+            yield o.source_journal
+
+    def get_target_journals(self):
+        # vtlist = [vt for vt in VoucherTypes.get_list_items()
+        #     # if issubclass(vt.table_class, self.journal_table)]
+        #     if issubclass(vt.model, dd.plugins.invoicing.voucher_model)]
+        # return rt.models.ledger.Journal.objects.filter(voucher_type__in=vtlist)
+        return rt.models.ledger.Journal.objects.filter(invoicing_area=self)
+
+
+class InvoicingAreas(dd.ChoiceList):
+    verbose_name = _("Invoicing area")
+    verbose_name_plural = _("Invoicing areas")
+    item_class = InvoicingArea
+    column_names = 'value name text target_journals'
+    required_roles = dd.login_required(LedgerStaff)
+
+    @dd.displayfield()
+    def target_journals(cls, choice, ar):
+        return ", ".join([jnl.ref for jnl in choice.get_target_journals()])
+
+
+add = InvoicingAreas.add_item
+add('invoices', _("Generate invoices"),  'default')
+# add('100', _("Promised"),  'promised')
+# add('200', _("Delivered"), 'delivered')  # 'sales.InvoicesByJournal'
+# add('300', _("Ordered"),  'ordered')
+# add('400', _("Received"),  'received')
+
+
+class InvoicingTargetVoucher(dd.Model):
+
+    class Meta:
+        abstract = True
+
+    if dd.is_installed("invoicing"):
+        invoicing_min_date = dd.DateField(_("Invoiceables from"), blank=True, null=True)
+        invoicing_max_date = dd.DateField(_("until"), blank=True, null=True)
+    else:
+        invoicing_min_date = dd.DummyField()
+        invoicing_max_date = dd.DummyField()
+
+
+class InvoicingTargetItem(dd.Model):
+
+    class Meta:
+        abstract = True
+
+    if dd.is_installed("invoicing"):
+
+        invoiceable_label = dd.plugins.invoicing.invoiceable_label
+
+        invoiceable_type = dd.ForeignKey(
+            ContentType,
+            blank=True, null=True,
+            verbose_name=format_lazy("{} {}", invoiceable_label, _('(type)')))
+        invoiceable_id = GenericForeignKeyIdField(
+            'invoiceable_type',
+            blank=True, null=True,
+            verbose_name=format_lazy("{} {}", invoiceable_label, _('(object)')))
+        invoiceable = GenericForeignKey(
+            'invoiceable_type', 'invoiceable_id',
+            verbose_name=invoiceable_label)
+
+        @dd.chooser()
+        def invoiceable_type_choices(cls):
+            # show only invoiceable models when selecting an invoiceable_type
+            return ContentType.objects.get_for_models(
+                *rt.models_by_base(InvoiceGenerator)).values()
+
+    else:
+        invoiceable_type = dd.DummyField()
+        invoiceable_id = dd.DummyField()
+        invoiceable = dd.DummyField()
+
+
 class InvoiceGenerator(dd.Model):
     # event_date_field = None
 
@@ -235,6 +337,11 @@ class InvoiceGenerator(dd.Model):
             content_type_field='invoiceable_type',
             object_id_field='invoiceable_id')
 
+        @dd.displayfield(_("Invoicing info"))
+        def invoicing_info(self, ar):
+            info = self.compute_invoicing_info(None, dd.today())
+            return info.format_as_html(ar)
+
     # @classmethod
     # def on_analyze(cls, site):
     #     super(InvoiceGenerator, cls).on_analyze(site)
@@ -245,12 +352,12 @@ class InvoiceGenerator(dd.Model):
     #     # if isinstance(cls.invoiceable_date_field, six.string_types):
     #     #     cls.invoiceable_date_field =
 
-    def get_invoicing_area(self):
-        return rt.models.invoicing.Area.objects.first()
-        # raise NotImplementedError()
-        # return None
-        # no longer overridden in Presto: return self.journal.room.invoicing_area
-        # overridden in orders.Order
+    # def get_invoicing_area(self):
+    #     return None
+    #     # return InvoicingAreas.delivered
+    #     # raise NotImplementedError()
+    #     # no longer overridden in Presto: return self.journal.room.invoicing_area
+    #     # overridden in orders.Order
 
     def get_invoicings(self, **kwargs):
         # deprecated. use invoicings instead.
@@ -286,13 +393,21 @@ class InvoiceGenerator(dd.Model):
         if info.number_of_events is None:
             # qty = asset_to_buy * info.invoiceable_qty
             qty = info.invoiceable_qty
-            kwargs.update(
-                title=self.get_invoiceable_title(), qty=qty)
+            title = self.get_invoiceable_title()
+            if info.sub_start or info.sub_end:
+                title += " " + rangefmt([info.sub_start, info.sub_end])
+            kwargs.update(title=title, qty=qty)
+            # print("20221224 gonna call add_voucher_item()", invoice.__class__,
+            #     invoice.journal,
+            #     invoice.journal.voucher_type.get_items_model())
             i = invoice.add_voucher_item(**kwargs)
             i.discount_changed(ar)
             yield i
             return
 
+        if info.sub_start or info.sub_end:
+            raise Exception("What is a subscription with number_of_events?")
+
         asset_to_buy = info.asset_to_buy
         if asset_to_buy is None:
             return
@@ -320,11 +435,6 @@ class InvoiceGenerator(dd.Model):
         # assert self._invoicing_info.generator is self
         return self._invoicing_info
 
-    @dd.displayfield(_("Invoicing info"))
-    def invoicing_info(self, ar):
-        info = self.compute_invoicing_info(None, dd.today())
-        return info.format_as_html(ar)
-
     def get_invoiceable_product(self, max_date=None):
         return None
 
@@ -383,13 +493,13 @@ class InvoiceGenerator(dd.Model):
     def get_generators_for_plan(cls, plan, partner=None):
         return cls.objects.all()
 
-    def setup_invoice_from_suggestion(self, invoice, plan, info):
-        if info.invoicing_max_date is not None:
-            invoice.invoicing_min_date = info.invoicing_min_date
-            invoice.invoicing_max_date = info.invoicing_max_date
-        else:
-            invoice.invoicing_min_date = plan.min_date
-            invoice.invoicing_max_date = plan.get_max_date()
+    # def setup_invoice_from_suggestion(self, invoice, plan, info):
+    #     if info.invoicing_max_date is not None:
+    #         invoice.invoicing_min_date = info.invoicing_min_date
+    #         invoice.invoicing_max_date = info.invoicing_max_date
+    #     else:
+    #         invoice.invoicing_min_date = plan.min_date
+    #         invoice.invoicing_max_date = plan.get_max_date()
 
     def setup_invoice_item(self, item):
         pass
