@@ -4,6 +4,7 @@
 
 from lino.api import dd, rt, _
 from lino_xl.lib.ledger.choicelists import DC, CommonAccounts
+from lino_xl.lib.invoicing.mixins import InvoicingAreas
 # from lino.utils import Cycler
 
 vat = dd.resolve_app('vat')
@@ -31,16 +32,13 @@ def objects():
     else:
         MODEL = vat.VatAccountInvoice
     kw.update(trade_type='sales')
-    # kw.update(ref="OFF", dc=DC.credit)
-    # kw.update(printed_name=_("Offer"))
-    # kw.update(dd.str2kw('name', _("Offers")))
-    # yield MODEL.create_journal(**kw)
 
     kw.update(ref="SLS", dc=DC.credit)
     kw.update(dd.str2kw('printed_name', _("Invoice")))
     # kw.update(dd.str2kw('name', _("Sales invoices")))
-    # kw.update(printed_name=_("Invoice"))
     kw.update(dd.str2kw('name', _("Sales invoices")))
+    # if dd.is_installed('invoicing'):
+    #     kw.update(invoicing_area=InvoicingAreas.default)
     SLS_JOURNAL = MODEL.create_journal(**kw)
     yield SLS_JOURNAL
 
@@ -53,6 +51,7 @@ def objects():
             country=dd.plugins.countries.get_my_country())
         yield misc_partner
         kw.update(partner=misc_partner)
+        # kw.update(invoicing_area=InvoicingAreas.delivered)
         if sales_method == "delivery":
             kw.update(ref="SDN", dc=DC.credit)
             kw.update(dd.str2kw('printed_name', _("Delivery note")))
@@ -67,9 +66,8 @@ def objects():
             raise Exception("Unsupported sales method {}".format(sales_method))
         SDN_JOURNAL = sales.CashInvoicesByJournal.create_journal(**kw)
         yield SDN_JOURNAL
-        yield rt.models.invoicing.FollowUpRule(
-            source_journal=SDN_JOURNAL,
-            target_journal=SLS_JOURNAL)
+        if sales_method == "delivery":
+            yield FollowUpRule(invoicing_area=InvoicingAreas.invoices, source_journal=SDN_JOURNAL)
         # yield PaymentMethod(designation=_("Cash payment"), journal=SDN_JOURNAL)
 
     if has_payment_methods:
