@@ -100,7 +100,7 @@ class Measurable(dd.Model):
     Usage
     =====
 
-    When some model inherits from Measurable it the model must define a `unit`
+    When some model inherits from Measurable, the model must define a `unit`
     field like the example below::
 
         class Potato(Food, Measurable):
@@ -116,7 +116,7 @@ class Measurable(dd.Model):
     In a ui layout, you can use the fields "unit value".
 
     WARNING: passing a value for the *value* field is invalid when a value for
-    the *unit* is not given!
+    the *unit* is not given (or NOT set already)!
 
     You can access the measurement object by accessing the .m (dot em) property
     of the Measurable subclasses, like so::
@@ -231,3 +231,6 @@ class Measurable(dd.Model):
                 self.measurement.unit.value:
                     getattr(self.measurement.value, self.measurement.unit.value)
             })
+
+    def __str__(self):
+        return str(self.m)
