@@ -12,31 +12,35 @@ from lino_xl.lib.ledger.choicelists import TradeTypes
 from lino_xl.lib.vat.mixins import QtyVatItemBase, VatVoucher
 from lino_xl.lib.vat.utils import add_vat, remove_vat
 from lino_xl.lib.vat.mixins import get_default_vat_regime, myround
+from lino_xl.lib.contacts.mixins import PartnerPrintable
 from lino_xl.lib.vat.choicelists import VatAreas, VatRules
 
 from lino.api import dd, rt, _
 
 
-class SalesDocument(VatVoucher, Certifiable):
+class SalesPrintable(PartnerPrintable, Certifiable):
+    class Meta:
+        abstract = True
+
+    subject = models.CharField(_("Subject line"), max_length=200, blank=True)
+    paper_type = dd.ForeignKey('sales.PaperType', null=True, blank=True)
+    # channel = Channels.field(default=Channels.as_callable('paper'))
+    def get_excerpt_templates(self, bm):
+        # Overrides lino_xl.lib.excerpts.mixins.Certifiable.get_excerpt_templates
+
+        pt = self.paper_type or get_paper_type(self.get_partner())
+        if pt and pt.template:
+            # print(20190506, pt.template)
+            return [pt.template]
+
+
+class SalesDocument(SalesPrintable, VatVoucher):
     class Meta:
         abstract = True
 
     edit_totals = False
 
-    # print_items_table = None
-
-    language = dd.LanguageField()
-    subject = models.CharField(_("Subject line"), max_length=200, blank=True)
     intro = models.TextField(_("Introductive text"), blank=True)
-    paper_type = dd.ForeignKey('sales.PaperType', null=True, blank=True)
-    # channel = Channels.field(default=Channels.as_callable('paper'))
-
-    def get_printable_type(self):
-        return self.journal
-
-    def get_print_language(self):
-        return self.language or self.partner.language or \
-            dd.get_default_language()
 
     def get_trade_type(self):
         return TradeTypes.sales
@@ -50,15 +54,7 @@ class SalesDocument(VatVoucher, Certifiable):
                 # qty = Duration(1)
         kw['product'] = product
         kw['qty'] = qty
-        return super(SalesDocument, self).add_voucher_item(**kw)
-
-    def get_excerpt_templates(self, bm):
-        # Overrides lino_xl.lib.excerpts.mixins.Certifiable.get_excerpt_templates
-
-        pt = self.paper_type or get_paper_type(self.partner)
-        if pt and pt.template:
-            # print(20190506, pt.template)
-            return [pt.template]
+        return super().add_voucher_item(**kw)
 
 dd.update_field(SalesDocument, 'total_base', editable=False)
 dd.update_field(SalesDocument, 'total_vat', editable=False)
@@ -89,7 +85,7 @@ class ProductDocItem(QtyVatItemBase):
     def get_default_vat_class(self, tt):
         if self.product and self.product.vat_class:
             return self.product.vat_class
-        return super(ProductDocItem, self).get_default_vat_class(tt)
+        return super().get_default_vat_class(tt)
 
     def discount_changed(self, ar=None):
         if not self.product:
@@ -130,7 +126,7 @@ class ProductDocItem(QtyVatItemBase):
             self.discount_changed(ar)
 
     def full_clean(self):
-        super(ProductDocItem, self).full_clean()
+        super().full_clean()
         if self.total_incl and not self.product:
             tt = self.voucher.get_trade_type()
             if self.get_base_account(tt) is None:
