@@ -1,9 +1,8 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2011-2022 Rumma & Ko Ltd
+# Copyright 2011-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 
-from rstgen.utils import py2url_txt
 from django.conf import settings
 from django.db import models
 from django.db.models import Q
@@ -18,7 +17,7 @@ from lino.mixins.ref import Referrable
 from lino.mixins.periods import DateRange
 from lino.modlib.comments.mixins import Commentable, PrivateCommentsReader, CommentField
 from lino.modlib.notify.choicelists import MessageTypes
-from lino.modlib.memo.mixins import rich_text_to_elems
+from lino.modlib.memo.mixins import rich_text_to_elems, MemoReferrable
 from lino.modlib.uploads.mixins import UploadController
 from lino.modlib.users.mixins import UserAuthored
 from lino.modlib.checkdata.choicelists import Checker
@@ -240,7 +239,7 @@ class Site(Referrable, ContactRelated, Starrable, DateRange):
         Currently only checks for is group member and role...
         """
 
-        if not super(Site, self).get_row_permission(ar, state, ba):
+        if not super().get_row_permission(ar, state, ba):
             return False
 
         if ((self.group and self.group.members.filter(user__id=ar.get_user().id).count() == 0)
@@ -252,7 +251,7 @@ class Site(Referrable, ContactRelated, Starrable, DateRange):
 
     @classmethod
     def get_user_queryset(cls, user):
-        qs = super(Site, cls).get_user_queryset(user)
+        qs = super().get_user_queryset(user)
         if user.is_anonymous:
             qs = qs.filter(private=False)
         elif not user.user_type.has_required_roles([TicketsStaff]):
@@ -262,7 +261,7 @@ class Site(Referrable, ContactRelated, Starrable, DateRange):
     @classmethod
     def add_param_filter(
             cls, qs, lookup_prefix='', show_exposed=None, **kwargs):
-        qs = super(Site, cls).add_param_filter(qs, **kwargs)
+        qs = super().add_param_filter(qs, **kwargs)
         exposed_states = SiteStates.filter(is_exposed=True)
         fkw = dict()
         fkw[lookup_prefix + 'state__in'] = exposed_states
@@ -445,11 +444,13 @@ class SpawnTicket(dd.Action):
 
 class Ticket(UserAuthored, mixins.CreatedModified, TimeInvestment,
              Votable, Starrable, Workable, Feasible,
-             UploadController, mixins.Referrable):
+             UploadController, Referrable, MemoReferrable):
+
     quick_search_fields = "summary description ref"
     workflow_state_field = 'state'
     create_session_on_create = True
     disable_author_assign = False
+    memo_command = "ticket"
 
     class Meta:
         app_label = 'tickets'
@@ -567,7 +568,7 @@ class Ticket(UserAuthored, mixins.CreatedModified, TimeInvestment,
 
     @classmethod
     def get_user_queryset(cls, user):
-        qs = super(Ticket, cls).get_user_queryset(user)
+        qs = super().get_user_queryset(user)
         if user.is_anonymous:
             qs = qs.filter(private=False, site__private=False)
         elif not user.user_type.has_required_roles([TicketsStaff]):
@@ -600,7 +601,7 @@ class Ticket(UserAuthored, mixins.CreatedModified, TimeInvestment,
     @classmethod
     def get_comments_filter(cls, user):
         if user.is_anonymous:
-            return super(Ticket, cls).get_comments_filter(user)
+            return super().get_comments_filter(user)
         if user.user_type.has_required_roles([PrivateCommentsReader]):
             return None
         flt = Q(ticket__site__group__members__user__id=user.pk)
@@ -653,7 +654,7 @@ class Ticket(UserAuthored, mixins.CreatedModified, TimeInvestment,
                 if qs.count():
                     # self.site = qs[0].site
                     self.site = qs.first()
-        super(Ticket, self).full_clean()
+        super().full_clean()
 
     def get_change_owner(self):
         if self.site_id is not None:
@@ -671,6 +672,25 @@ class Ticket(UserAuthored, mixins.CreatedModified, TimeInvestment,
         self.full_clean()
         self.save()
 
+    def memo2html(self, ar, text, **kwargs):
+        # if txt:
+        #     kwargs.update(title=txt)
+        kwargs.update(title=text or self.summary)
+        e = self.obj2href(ar, "#{}".format(self.pk), **kwargs)
+        return tostring(e)
+        # return ar.obj2str(self, "#{}".format(self.pk), **kwargs)
+
+    def obj2memo(self, text=None):
+        """Render the given database object as memo markup.
+        """
+        if self.memo_command is None:
+            return "**{}**".format(self)
+        return "[{} {}] ({})".format(self.memo_command, self.id, self.summary)
+
+    # def get_memo_title(self):
+    #     # don't show the ticket number in the title
+    #     return self.summary
+
     def get_comment_group(self):
         return self.site
 
@@ -689,12 +709,17 @@ class Ticket(UserAuthored, mixins.CreatedModified, TimeInvestment,
     #         return qs[0].project
     #     return rt.models.tickets.Project.objects.all()[0]
 
-    def obj2href(self, ar, **kwargs):
-        kwargs.update(title=self.summary)
-        return ar.obj2html(self, "#{}".format(self.id), **kwargs)
+    def obj2href(self, ar, text=None, **kwargs):
+        if not 'title' in kwargs:
+            kwargs.update(title=self.summary)
+        if not text:
+            text = "#{}".format(self.id)
+        # if self.ref is not None:
+        #     return ar.obj2html(self, "#{}".format(self.ref), *args, **kwargs)
+        return ar.obj2html(self, text, **kwargs)
 
     def disabled_fields(self, ar):
-        rv = super(Ticket, self).disabled_fields(ar)
+        rv = super().disabled_fields(ar)
         # if self.project and not self.project.private:
         #     rv.add('private')
         if not ar.get_user().user_type.has_required_roles([Triager]):
@@ -704,17 +729,12 @@ class Ticket(UserAuthored, mixins.CreatedModified, TimeInvestment,
             # rv.add('fixed_time')
         return rv
 
-    # def get_choices_text(self, request, actor, field):
-    #     return "{0} ({1})".format(self, self.summary)
-
     def __str__(self):
         # if self.nickname:
         #     return "#{0} ({1})".format(self.id, self.nickname)
-        if False and self.state.button_text:
-            return "#{0} ({1} {2})".format(
-                self.id, self.state.button_text, self.summary)
-        return "#{0} ({1} {2})".format(
-            self.id, self.state.button_text, self.summary)
+        # return "#{0} ({1} {2})".format(
+        #     self.id, self.state.button_text, self.summary)
+        return "#{} ({})".format(self.id, self.summary)
 
     @dd.chooser()
     def reported_for_choices(cls, site):
@@ -803,7 +823,7 @@ class Ticket(UserAuthored, mixins.CreatedModified, TimeInvestment,
         """
         To skip mixins.Referrable quick_search_filter
         """
-        return super(mixins.Referrable, cls).quick_search_filter(search_text, prefix)
+        return super().quick_search_filter(search_text, prefix)
 
 Ticket.set_widget_options('priority', preferred_width=8, hide_sum=True)
 
@@ -842,19 +862,11 @@ def setup_memo_commands(sender=None, **kwargs):
     Ticket = sender.models.tickets.Ticket
     mp = sender.plugins.memo.parser
 
-    mp.register_django_model(
-        'ticket', Ticket, title=lambda obj: obj.summary)
+    # mp.register_django_model(
+    #     'ticket', Ticket, title=lambda obj: obj.summary)
     mp.add_suggester(
-        "#", sender.models.tickets.Ticket.objects.order_by('id'), 'id')
+        "#", Ticket.objects.order_by('id'), 'id')
 
-    def py2html(parser, s, cmdname, usages):
-        url, txt = py2url_txt(s)
-        if url:
-            # lines = inspect.getsourcelines(s)
-            return '<a href="{0}" target="_blank">{1}</a>'.format(url, txt)
-        return "<pre>{}</pre>".format(s)
-
-    mp.register_command('py', py2html)
 
 
 from .ui import *
