@@ -14,7 +14,7 @@ Usage:
 - Add ``'tim2lino'`` to your
   :attr:`demo_fixtures <lino.core.site.Site.demo_fixtures>`.
 
-- Run :manage:`prep`.
+- Run :cmd:`pm prep`.
 
 """
 from __future__ import unicode_literals
