@@ -21,6 +21,14 @@ class Plugin(ad.Plugin):
     # project_model = 'tickets.Project'
     # project_model = 'contacts.Partner'
 
+    reports_master = 'sales.VatProductInvoice'
+    """
+    The model used as the master for service reports.
+
+    This model must have three fields company, start_date and end_date.
+
+    """
+
     ticket_model = 'tickets.Ticket'
     # ticket_model = 'contacts.Partner'
     """
