@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2016-2022 Rumma & Ko Ltd
+# Copyright 2016-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 
@@ -29,7 +29,7 @@ class Workable(dd.Model):
         end_session = EndTicketSession()
 
         def disabled_fields(self, ar):
-            s = super(Workable, self).disabled_fields(ar)
+            s = super().disabled_fields(ar)
             user = ar.get_user()
             if not (user.is_authenticated and self.is_workable_for(user)):
                 s.add('start_session')
