@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2011-2022 Rumma & Ko Ltd
+# Copyright 2011-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 import datetime as dt
 from copy import copy
@@ -73,6 +73,7 @@ class Session(UserAuthored, Started, Ended, Workable, InvoiceGenerator):
     #     blank=True, null=True,
     #     verbose_name=_("Break Time"))
     break_time = dd.DurationField(_("Break Time"), blank=True, null=True)
+    computed_duration = dd.DurationField(_("Duration"), blank=True, null=True)
     faculty = dd.ForeignKey(
         'skills.Skill', related_name="sessions_by_faculty",
         blank=True, null=True)
@@ -146,6 +147,8 @@ class Session(UserAuthored, Started, Ended, Workable, InvoiceGenerator):
             if self.ticket_id:
                 self.ticket.on_worked(self)
 
+            self.computed_duration = self.compute_duration()
+
         super().full_clean(*args, **kwargs)
 
     def unused_save(self, *args, **kwargs):
@@ -156,6 +159,40 @@ class Session(UserAuthored, Started, Ended, Workable, InvoiceGenerator):
                 self.start_time = timezone.now().time()
         super().save(*args, **kwargs)
 
+    def compute_duration(self):
+        duration = super().get_duration()
+        if duration:
+            if self.break_time:
+                duration -= self.break_time
+            for obj in self.get_sub_sessions():
+                if obj.computed_duration:
+                    duration -= obj.computed_duration
+            assert type(duration) is Duration
+        return duration
+
+    def get_sub_sessions(self):
+        if self.end_date == self.start_date:
+            # print("20230117 single-day")
+            qs = self.__class__.objects.filter(
+                user=self.user,
+                start_date=self.start_date, end_date=self.end_date,
+                start_time__gte=self.start_time, end_time__lte=self.end_time)
+            qs = qs.exclude(id=self.id)
+            return qs
+        assert self.end_date > self.start_date  # has been working overnight
+        # print("20230117 multi-day")
+        qs = self.__class__.objects.filter(
+            user=self.user,
+            start_date__gte=self.start_date, end_date__lte=self.end_date)
+        qs = qs.exclude(id=self.id)
+        st = self.get_datetime('start')
+        et = self.get_datetime('end')
+        for obj in qs.order_by('start_date', 'start_time'):
+            # print("20230117", obj)
+            if obj.get_datetime('start') >= st:
+                if obj.get_datetime('end') <= et:
+                    yield obj
+
     def get_reporting_type(self):
         if self.reporting_type:
             return self.reporting_type
@@ -182,25 +219,12 @@ class Session(UserAuthored, Started, Ended, Workable, InvoiceGenerator):
             return self.ticket.project.get_parental_line()[0]
 
     def get_duration(self):
-        """Return the duration in hours as a
-        :class:`lino.utils.quantities.Quantity`.  This inherits from
-        :meth:`StartedEnded
-        <lino_xl.lib.cal.mixins.StartedEnded.get_duration>` but
-        removes :attr:`break_time` if specified.
-
         """
-        diff = super().get_duration()
-        if diff and self.break_time:
-            diff -= self.break_time
-        return diff
+        Overrides :meth:`StartedEnded.get_duration
+        <lino_xl.lib.cal.StartedEnded.get_duration>`
+        """
+        return self.computed_duration
 
-        # if self.end_time is None:
-        #     diff = datetime.timedelta()
-        # else:
-        #     diff = self.get_datetime('end') - self.get_datetime('start')
-        #     if self.break_time is not None:
-        #         diff -= self.break_time
-        # return Duration(diff)
 
     @dd.displayfield(_("Ticket #"))
     def ticket_no(self, ar):
